import { ModalFormData, MessageFormData, ActionFormData } from "@minecraft/server-ui"
import { world } from "@minecraft/server"
import { api } from "./api.js"

const options = ["a-z", "z-a", "last"]

export const ui = new class{
    // Create Waypoint
    0(player, waypoints){
        new ModalFormData()
        .title("waypoint.ui.create.title")
        .textField("waypoint.ui.create.textfieldText", "waypoint.ui.create.textfieldHolder")
        .submitButton("waypoint.ui.create.buttonSave")
        .show(player).then(r => {
            if(r.canceled) return player.onScreenDisplay.setActionBar({translate: "waypoint.warning.cancelCreatePoint"})
            if(!r.formValues[0]) return player.onScreenDisplay.setActionBar({translate: "waypoint.warning.failCreatePoint"})
            api.saveNewPoint(player, r.formValues[0], waypoints)
        })
    }

    // Delete Waypoint
    1(player, waypoints){
        if(waypoints.length < 1) return player.onScreenDisplay.setActionBar({translate: "waypoint.warning.dontHavePoints"})
        new ModalFormData()
        .title("waypoint.ui.delete.title")
        .dropdown("waypoint.ui.delete.dropdown", waypoints.map(way => way.id))
        .submitButton("waypoint.ui.delete.buttonDelete")
        .show(player).then(r => {
            if(r.canceled) return player.onScreenDisplay.setActionBar({translate: "waypoint.warning.dontDelete"})
            const point = waypoints[r.formValues[0]]
            new MessageFormData()
            .title("waypoint.ui.delete.title")
            .body({translate: "waypoint.ui.delete.confirm", with: [point.id, `${point.pos.x -0.5}, ${point.pos.y}, ${point.pos.z -0.5}`]})
            .button1("waypoint.ui.yes")
            .button2("waypoint.ui.no")
            .show(player).then(r2 => {
                if(r2.canceled) return player.onScreenDisplay.setActionBar({translate: "waypoint.warning.dontDelete"})
                if(r2.selection == 1) return player.onScreenDisplay.setActionBar({translate: "waypoint.warning.dontDelete"})
                waypoints.splice(r.formValues[0], 1)
                api.saveAllPoints(player, waypoints)
                player.setDynamicProperty(`currentWaypoint${player.dimension.id}`, false)
                player.onScreenDisplay.setActionBar({translate: "waypoint.warning.deleted", with: [point.id]})
            })
        })
    }

    // Waypoints Options
    2(player){
        new ActionFormData()
        .title("waypoint.ui.options.title")
        .button("waypoint.ui.options.organize.title")
        .button("waypoint.ui.options.general.title")
        .show(player).then(r => {
            if(r.canceled) return
            waypointOptions[r.selection](player)
        })
    }
}

const waypointOptions = new class{
    // Organize Waypoints
    0(player){
        const config = JSON.parse(player.getDynamicProperty("waypointConfig"))
        new ModalFormData()
        .title("waypoint.ui.options.organize.title")
        .dropdown("waypoint.ui.options.organize.dropdown", ["a-z", "z-a", {translate: "waypoint.ui.options.organize.dropdown.last"}], options.findIndex(t => config.organizeType == t))
        .submitButton("waypoint.ui.options.organize.buttonOrganize")
        .show(player).then(r => {
            if(r.canceled) return player.onScreenDisplay.setActionBar({translate: "waypoint.warning.cancelOrganizePoints"})
            config.organizeType = options[r.formValues[0]]
            player.setDynamicProperty("waypointConfig", JSON.stringify(config))
            if(r.formValues[0] < 2){
                player.onScreenDisplay.setActionBar({translate: "waypoint.ui.options.organize.organizePoints", with: [options[r.formValues[0]]]})
            } else {
                player.onScreenDisplay.setActionBar({translate: "waypoint.ui.options.organize.organizePointsLast"})
            }
        })
    }

    // General Settings
    1(player){
        const config = JSON.parse(player.getDynamicProperty("waypointConfig"))
        const form = new ModalFormData()
        .title("waypoint.ui.options.general.title")
        .toggle("waypoint.ui.options.general.toggle.showCoordinates", config.showCoordinates)
        .toggle("waypoint.ui.options.general.toggle.showDistance", config.showDistance)
        if(player.getGameMode() == "creative") form.toggle("waypoint.ui.options.general.toggle.cheatTeleport", config.teleport)
        form.submitButton("waypoint.ui.create.buttonSave")
        .show(player).then(r => {
            if(r.canceled) return player.onScreenDisplay.setActionBar({translate: "waypoint.warning.cancelOptions"})
            config.showCoordinates = r.formValues[0]
            config.showDistance = r.formValues[1]
            if(r.formValues[2] != undefined) config.teleport = r.formValues[2]
            player.setDynamicProperty("waypointConfig", JSON.stringify(config))
            player.onScreenDisplay.setActionBar({translate: "waypoint.warning.saveOptions"})
        })
    }
}