import { ActionFormData } from "@minecraft/server-ui"
import { world } from "@minecraft/server"
import { api } from "./api.js"
import { ui } from "./ui.js"

export const waypoint = new class{
    selectWaypoint(player){
        const config = JSON.parse(player.getDynamicProperty("waypointConfig"))
        const waypoints = api.organize(api.getAllWaypoints(player, player.getDynamicPropertyIds()), config.organizeType)
        if(waypoints.length < 1) return player.onScreenDisplay.setActionBar({translate: "waypoint.warning.dontHavePoints"})
        const buttons = waypoints.map(way => config.showCoordinates ? `${way.id}\n${way.pos.x - 0.5}, ${way.pos.y}, ${way.pos.z - 0.5}` : `${way.id}`)
        const form = new ActionFormData()
        .title("waypoint.ui.select.title")
        buttons.forEach(b => { form.button(b) })
        form.show(player).then(r => {
            if(r.canceled) return
            api.resetLastUse(waypoints)
            waypoints[r.selection].last = true
            if(!config.teleport){
                player.setDynamicProperty(`currentWaypoint${player.dimension.id}`, JSON.stringify({pos: waypoints[r.selection].pos, dimension: waypoints[r.selection].dimension}))
                if(config.showDistance) player.sendMessage({translate: "waypoint.warning.distance", with: [waypoints[r.selection].id, api.getDistace(player.location, waypoints[r.selection].pos)]})
            } else {
                player.setDynamicProperty(`currentWaypoint${player.dimension.id}`, false)
                player.teleport(waypoints[r.selection].pos)
            }
            api.saveAllPoints(player, waypoints)
        })
    }

    configMenu(player){
        const config = JSON.parse(player.getDynamicProperty("waypointConfig"))
        const waypoints = api.organize(api.getAllWaypoints(player, player.getDynamicPropertyIds()), config.organizeType)
        new ActionFormData()
        .title("waypoint.ui.config.title")
        .button("waypoint.ui.config.button.create")
        .button("waypoint.ui.config.button.delete")
        .button("waypoint.ui.config.button.options")
        .show(player).then(r => {
            if(r.canceled) return
            ui[r.selection](player, waypoints)
        })
    }
}